==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/PipelineRunRequestArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The request properties provided for a pipeline run.
 * @property artifacts List of source artifacts to be transferred by the pipeline.
 * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
 * Specify an image by tag ('hello-world:latest').
 * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
 * @property catalogDigest The digest of the tar used to transfer the artifacts.
 * @property pipelineResourceId The resource ID of the pipeline to run.
 * @property source The source properties of the pipeline run.
 * @property target The target properties of the pipeline run.
 */
public data class PipelineRunRequestArgs(
    public val artifacts: Output<List<String>>? = null,
    public val catalogDigest: Output<String>? = null,
    public val pipelineResourceId: Output<String>? = null,
    public val source: Output<PipelineRunSourcePropertiesArgs>? = null,
    public val target: Output<PipelineRunTargetPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs =
        com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs.builder()
            .artifacts(artifacts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .catalogDigest(catalogDigest?.applyValue({ args0 -> args0 }))
            .pipelineResourceId(pipelineResourceId?.applyValue({ args0 -> args0 }))
            .source(source?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .target(target?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PipelineRunRequestArgs].
 */
@PulumiTagMarker
public class PipelineRunRequestArgsBuilder internal constructor() {
    private var artifacts: Output<List<String>>? = null

    private var catalogDigest: Output<String>? = null

    private var pipelineResourceId: Output<String>? = null

    private var source: Output<PipelineRunSourcePropertiesArgs>? = null

    private var target: Output<PipelineRunTargetPropertiesArgs>? = null

    /**
     * @param value List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("ibjjfmrhdlyatppk")
    public suspend fun artifacts(`value`: Output<List<String>>) {
        this.artifacts = value
    }

    @JvmName("quvurpairqewvvkv")
    public suspend fun artifacts(vararg values: Output<String>) {
        this.artifacts = Output.all(values.asList())
    }

    /**
     * @param values List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("qyjfxxfmdykkhjmp")
    public suspend fun artifacts(values: List<Output<String>>) {
        this.artifacts = Output.all(values)
    }

    /**
     * @param value The digest of the tar used to transfer the artifacts.
     */
    @JvmName("badowtyauwvyrjmq")
    public suspend fun catalogDigest(`value`: Output<String>) {
        this.catalogDigest = value
    }

    /**
     * @param value The resource ID of the pipeline to run.
     */
    @JvmName("ydaquijbusgxemfu")
    public suspend fun pipelineResourceId(`value`: Output<String>) {
        this.pipelineResourceId = value
    }

    /**
     * @param value The source properties of the pipeline run.
     */
    @JvmName("gesaycrbndwjabxt")
    public suspend fun source(`value`: Output<PipelineRunSourcePropertiesArgs>) {
        this.source = value
    }

    /**
     * @param value The target properties of the pipeline run.
     */
    @JvmName("ejlofapdgqvtlhvl")
    public suspend fun target(`value`: Output<PipelineRunTargetPropertiesArgs>) {
        this.target = value
    }

    /**
     * @param value List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("rhypcanesjdaitjo")
    public suspend fun artifacts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    /**
     * @param values List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("sgmysmnafskxetoh")
    public suspend fun artifacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    /**
     * @param value The digest of the tar used to transfer the artifacts.
     */
    @JvmName("kwfenbjpeixyacqp")
    public suspend fun catalogDigest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogDigest = mapped
    }

    /**
     * @param value The resource ID of the pipeline to run.
     */
    @JvmName("piuguqprkarkbiyf")
    public suspend fun pipelineResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelineResourceId = mapped
    }

    /**
     * @param value The source properties of the pipeline run.
     */
    @JvmName("hokwyvithspibtnb")
    public suspend fun source(`value`: PipelineRunSourcePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param argument The source properties of the pipeline run.
     */
    @JvmName("orxsrvhaccqbfril")
    public suspend fun source(argument: suspend PipelineRunSourcePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineRunSourcePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.source = mapped
    }

    /**
     * @param value The target properties of the pipeline run.
     */
    @JvmName("kwndqpysxpmkellx")
    public suspend fun target(`value`: PipelineRunTargetPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param argument The target properties of the pipeline run.
     */
    @JvmName("rutwscsybvhmqbfh")
    public suspend fun target(argument: suspend PipelineRunTargetPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineRunTargetPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.target = mapped
    }

    internal fun build(): PipelineRunRequestArgs = PipelineRunRequestArgs(
        artifacts = artifacts,
        catalogDigest = catalogDigest,
        pipelineResourceId = pipelineResourceId,
        source = source,
        target = target,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/PipelineRunRequestArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The request properties provided for a pipeline run.
 * @property artifacts List of source artifacts to be transferred by the pipeline.
 * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
 * Specify an image by tag ('hello-world:latest').
 * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
 * @property catalogDigest The digest of the tar used to transfer the artifacts.
 * @property pipelineResourceId The resource ID of the pipeline to run.
 * @property source The source properties of the pipeline run.
 * @property target The target properties of the pipeline run.
 */
public data class PipelineRunRequestArgs(
    public val artifacts: Output<List<String>>? = null,
    public val catalogDigest: Output<String>? = null,
    public val pipelineResourceId: Output<String>? = null,
    public val source: Output<PipelineRunSourcePropertiesArgs>? = null,
    public val target: Output<PipelineRunTargetPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs =
        com.pulumi.azurenative.containerregistry.inputs.PipelineRunRequestArgs.builder()
            .artifacts(artifacts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .catalogDigest(catalogDigest?.applyValue({ args0 -> args0 }))
            .pipelineResourceId(pipelineResourceId?.applyValue({ args0 -> args0 }))
            .source(source?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .target(target?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PipelineRunRequestArgs].
 */
@PulumiTagMarker
public class PipelineRunRequestArgsBuilder internal constructor() {
    private var artifacts: Output<List<String>>? = null

    private var catalogDigest: Output<String>? = null

    private var pipelineResourceId: Output<String>? = null

    private var source: Output<PipelineRunSourcePropertiesArgs>? = null

    private var target: Output<PipelineRunTargetPropertiesArgs>? = null

    /**
     * @param value List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("wihfisivpfytgeji")
    public suspend fun artifacts(`value`: Output<List<String>>) {
        this.artifacts = value
    }

    @JvmName("lhffsxsrxgampwpi")
    public suspend fun artifacts(vararg values: Output<String>) {
        this.artifacts = Output.all(values.asList())
    }

    /**
     * @param values List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("itnltubgsbobesqx")
    public suspend fun artifacts(values: List<Output<String>>) {
        this.artifacts = Output.all(values)
    }

    /**
     * @param value The digest of the tar used to transfer the artifacts.
     */
    @JvmName("gurdbcqgoyrtfdeq")
    public suspend fun catalogDigest(`value`: Output<String>) {
        this.catalogDigest = value
    }

    /**
     * @param value The resource ID of the pipeline to run.
     */
    @JvmName("ygxrxxhycjnhsths")
    public suspend fun pipelineResourceId(`value`: Output<String>) {
        this.pipelineResourceId = value
    }

    /**
     * @param value The source properties of the pipeline run.
     */
    @JvmName("afjqbinunfunjsnf")
    public suspend fun source(`value`: Output<PipelineRunSourcePropertiesArgs>) {
        this.source = value
    }

    /**
     * @param value The target properties of the pipeline run.
     */
    @JvmName("jjfnvjcvsgahfoga")
    public suspend fun target(`value`: Output<PipelineRunTargetPropertiesArgs>) {
        this.target = value
    }

    /**
     * @param value List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("ulvtuevqxffrhlox")
    public suspend fun artifacts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    /**
     * @param values List of source artifacts to be transferred by the pipeline.
     * Specify an image by repository ('hello-world'). This will use the 'latest' tag.
     * Specify an image by tag ('hello-world:latest').
     * Specify an image by sha256-based manifest digest ('hello-world@sha256:abc123').
     */
    @JvmName("dhkvcqarluukrtym")
    public suspend fun artifacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    /**
     * @param value The digest of the tar used to transfer the artifacts.
     */
    @JvmName("nugtemcxdafegqgg")
    public suspend fun catalogDigest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogDigest = mapped
    }

    /**
     * @param value The resource ID of the pipeline to run.
     */
    @JvmName("dqexriqabveictgd")
    public suspend fun pipelineResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pipelineResourceId = mapped
    }

    /**
     * @param value The source properties of the pipeline run.
     */
    @JvmName("rbtbdvwhffimchrp")
    public suspend fun source(`value`: PipelineRunSourcePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param argument The source properties of the pipeline run.
     */
    @JvmName("reukgjrtxwvnuimc")
    public suspend fun source(argument: suspend PipelineRunSourcePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineRunSourcePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.source = mapped
    }

    /**
     * @param value The target properties of the pipeline run.
     */
    @JvmName("njxfrcghscosulfv")
    public suspend fun target(`value`: PipelineRunTargetPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param argument The target properties of the pipeline run.
     */
    @JvmName("glbcvshwiisoabla")
    public suspend fun target(argument: suspend PipelineRunTargetPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = PipelineRunTargetPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.target = mapped
    }

    internal fun build(): PipelineRunRequestArgs = PipelineRunRequestArgs(
        artifacts = artifacts,
        catalogDigest = catalogDigest,
        pipelineResourceId = pipelineResourceId,
        source = source,
        target = target,
    )
}
